searchData={"items":[{"type":"module","title":"Marker","doc":"# Marker\n\n  `Marker` strives to be the most convenient tool for writing html markup in Elixir. It allows writing markup with Elixir syntax, while reaching the performance of precompiled templates.\n\n  Here's an example to give you an idea how `Marker` looks:\n\n```elixir\nuse Marker.HTML\n\nname = \"Vincent\"\n\nhtml do\n  body do\n    div do\n      h3 \"Person\"\n      p name, class: \"name\"\n      p 2 * 19, class: \"age\"\n    end\n  end\nend\n```\n\n  The above will result in:\n\n```elixir\n{:safe,\n\"<!doctype html>\\n    Person  Vincent  38    \"}\n```\n\n  `Marker` escapes all strings by default. In order to prevent an already escaped result from being escaped again when passed as an argument to another element, compiled results are wrapped in a `{:safe, ...}` tuple to mark the result as escaped. The Phoenix framework uses this idiom too. Besides escaping strings, `Marker` provides the `Marker.Encoder` protocol for encoding terms to one of Markers internal data types. See the protocol documentation for more info.\n\n  `Marker` is very flexible with the arguments you can pass to its element macro's:\n\n```elixir\niex> use Marker.HTML\n...> Marker.HTML\niex> div 42\n{:safe, \" 42 \"}\niex> div do: 42\n{:safe, \" 42 \"}\niex> div do\n...>   42\n...> end\n{:safe, \" 42 \"}\niex> div class: \"test\"\n{:safe, \"  \"}\niex> div [class: \"test\"], 42\n{:safe, \" 42 \"}\niex> div 42, class: \"test\"\n{:safe, \" 42 \"}\niex> div class: \"test\" do\n...>   42\n...> end\n{:safe, \" 42 \"}\n\n```\n\n  You can basicly do anything you like with argument order, as long as attributes are always a `Keyword` literal.","ref":"Marker.html"},{"type":"module","title":"Templates and Components - Marker","doc":"`Marker` provides templates and components as a convenient abstraction. A template is just a function with one argument. It expects a data structure that can be accessed with the `Access` protocol, like `Map` or `Keyword`. The fields of the argument can be accessed with the `@` attribute syntax. This works because templates and components provide an implementation of the `assigns` extension of `EEx` templates for easy data access. Components are like templates, but in adition to the template function, they define a macro that can be called just like the element macros. The contents of the `do` block of a component are accessable as `@__content__` in the component definition and is always wrapped in a list. A small, but important difference between templates and components is that an unavailable assign in a template raises a `RuntimeError`, as assigns are considered mandatory for templates, but they are optional for components. This makes it for example possible to define a component that optionally accepts a custom class.\n\n  An example makes this all probably much easier to understand, so here are a few components that could make using Bootstrap simpler:\n\n```elixir\ndefmodule MyComponents do\n  use Marker\n\n  component :form_input do\n    custom_classes = @class || \"\"\n    div class: \"form-group\" do\n      label @label, for: @id\n      input id: @id,\n            type: @type,\n            class: \"form-control \" <> custom_classes\n            placeholder: @placeholder,\n            value: @value\n    end\n  end\n\n  component :form_select do\n    custom_classes = @class || \"\"\n    div class: \"form-group\" do\n      label @label, for: @id\n      select @__content__, id: @id, class: \"form-control \" <> custom_classes\n    end\n  end\n\n  template :test do\n    html body do\n    h1 @title\n    form do\n        form_input id: \"form-address\", label: \"Address\", placeholder: \"Fill in address\"\n        form_select id: \"form-country\", label: \"Country\", class: \"country-select\" do\n          option \"Netherlands\", value: \"NL\"\n          option \"Belgium\", value: \"BE\"\n          option \"Luxembourg\", value: \"LU\"\n        end\n      end\n    end\n  end\nend\n\ntest title: \"My test form\"\n```\n\n  If you want to use components from another module, don't forget to `require` or `import` the module, since components are defined as macros.","ref":"Marker.html#module-templates-and-components"},{"type":"module","title":"Custom elements - Marker","doc":"`Marker` also allow you to define custom elements like this:\n\n```elixir\ndefmodule MyElements do\n  use Marker.Element, tags: [:my_element, :another_one]\nend\n```\n\n  You can now use your custom elements like the default elements:\n\n```elixir\nuse MyElements\n\nmy_element id: 42 do\n  another_one \"Hello world\"\nend\n```\n\n  Which will result in:\n\n```elixir\n{:safe, \"  Hello world  \"}\n```","ref":"Marker.html#module-custom-elements"},{"type":"module","title":"Installation - Marker","doc":"Add `marker` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:marker, \"~> 2.0\"}]\nend\n```","ref":"Marker.html#module-installation"},{"type":"module","title":"Using Marker with the Phoenix framework - Marker","doc":"Integrating `Marker` in your Phoenix project is very simple. It even makes working with Phoenix somewhat easier, since you don't need any templates anymore.\n\n  First add `marker` to your dependencies, then add Marker functions and components to your views and call them from the view's render function:\n\n```elixir\ndefmodule MyProject.PageView do\n  use MyProject.Web, :view\n  use Marker\n\n  template :greeter do\n    div do\n      h3 \"Hello \" <> @name\n      p \"(from Marker)\"\n    end\n  end\n\n  def render \"index.html\", assigns do\n    greeter name: \"World\"\n  end\nend\n```\n\n  If you plan to use `Marker` for all your views, you can add the `use Marker` directive to ` .Web.view/0`, so you don't need to specify these in every view.\n\n  A more complete example of how to use `Marker` with the Phoenix framework can be found [here](https://github.com/zambal/marker-phoenix-example)","ref":"Marker.html#module-using-marker-with-the-phoenix-framework"},{"type":"module","title":"Background - Marker","doc":"`Marker` is the successor of [Eml](https://github.com/zambal/eml). While `Eml` has many more features than `Marker`, sometimes less really is more. Apart from writing markup with Elixir syntax, `Eml` also supports parsing of HTML and provides extensive querying capabilities. However, I personally almost never used all these extra features, while writing markup had some unpleasant corner cases, fundamental to `Eml`'s design.\n\n  You could say that where `Eml` is like a swiss army knife, `Marker` tries to do one thing and do it as good as possible.\n\n# License\n\n  Marker is Copyright (C) 2016 by Vincent Siliakus and released under the [Apache License, Version 2.0](https://www.apache.org/licenses/LICENSE-2.0.html).","ref":"Marker.html#module-background"},{"type":"macro","title":"Marker.component/2","doc":"Define a new component","ref":"Marker.html#component/2"},{"type":"type","title":"Marker.content/0","doc":"","ref":"Marker.html#t:content/0"},{"type":"macro","title":"Marker.template/2","doc":"Define a new template","ref":"Marker.html#template/2"},{"type":"module","title":"Marker.Compiler","doc":"`Marker.Compiler` renders the element macros to html. It tries do as much work during macro expansion,\nresulting in a run time performance comparible to precompiled templates.\n\nFor example, this element call:\n\n```elixir\ndiv 1 + 1\n```\n\nwill be expanded to this:\n\n```elixir\n\" \" <> Marker.Encoder.encode(1 + 1) <> \" \"\n```","ref":"Marker.Compiler.html"},{"type":"type","title":"Marker.Compiler.chunks/0","doc":"","ref":"Marker.Compiler.html#t:chunks/0"},{"type":"type","title":"Marker.Compiler.element/0","doc":"","ref":"Marker.Compiler.html#t:element/0"},{"type":"module","title":"Marker.Element","doc":"This module is responsible for generating element macro's. Marker generates by default all html5 elements,\n  but you can easily generate other elements too:\n\n```elixir\ndefmodule MyElements do\n  use Marker.Element, tags: [:my_element, :another_one]\nend\n```\n\n  You can now use your custom elements like the default elements:\n\n```elixir\nuse MyElements\n\nmy_element id: 42 do\n  another_one \"Hello world\"\nend\n```\n\n  Which will result in:\n\n```elixir\n{:safe, \"  Hello world  \"}\n```","ref":"Marker.Element.html"},{"type":"module","title":"Casing - Marker.Element","doc":"You can control the casing of the generated elements too:\n\n```elixir\ndefmodule MyElements do\n  use Marker.Element, casing: :camel, tags: [:my_element, :another_one]\nend\n\nmy_element id: 42 do\n  another_one \"Hello world\"\nend\n\n{:safe, \"  Hello world  \"}\n```\n\nThe following casing options are allowed:\n\n  * `:snake` => `my_element` (default)\n  * `:snake_upcase` => `MY_ELEMENT`\n  * `:pascal` => `MyElement`\n  * `:camel` => `myElement`\n  * `:lisp` => `my-element`\n  * `:lisp_upcase` => `MY-ELEMENT`","ref":"Marker.Element.html#module-casing"},{"type":"type","title":"Marker.Element.attr_name/0","doc":"","ref":"Marker.Element.html#t:attr_name/0"},{"type":"type","title":"Marker.Element.attr_value/0","doc":"","ref":"Marker.Element.html#t:attr_value/0"},{"type":"type","title":"Marker.Element.attrs/0","doc":"","ref":"Marker.Element.html#t:attrs/0"},{"type":"type","title":"Marker.Element.t/0","doc":"","ref":"Marker.Element.html#t:t/0"},{"type":"protocol","title":"Marker.Encoder","doc":"The Marker Encoder protocol.\n\nThis protocol is used by Marker's compiler to convert different Elixir\ndata types to it's `Marker.Compiler.element` type.\n\nElements can be of the type `String.t`,\n`Marker.Element.t`, or `Macro.t`, so any implementation of the\n`Marker.Encoder` protocol needs to return one of these types.\nStrings are expected to be escaped.\n\nThe following types are implemented by default:\n\n`Integer`, `Float`, `Atom`, `Tuple`, `BitString` 'Date', 'DateTime',\n'NaiveDateTime' and `Marker.Element`\n\nYou can easily implement a protocol implementation for a custom\ntype, by defining an `encode` function that receives the custom type\nand outputs to `Marker.Compiler.element`.","ref":"Marker.Encoder.html"},{"type":"protocol","title":"Example - Marker.Encoder","doc":"iex> defmodule Customer do\n    ...>   defstruct [:name, :email, :phone]\n    ...> end\n    iex> defimpl Marker.Encoder, for: Customer do\n    ...>   def encode(%Customer{name: name, email: email, phone: phone}) do\n    ...>     use Marker\n    ...>\n    ...>     div class: \"customer\" do\n    ...>       div [span(\"name: \"), span(name)]\n    ...>       div [span(\"email: \"), span(email)]\n    ...>       div [span(\"phone: \"), span(phone)]\n    ...>     end\n    ...>   end\n    ...> end\n    iex> c = %Customer{name: \"Fred\", email: \"freddy@mail.com\", phone: \"+31 6 5678 1234\"}\n    %Customer{email: \"freddy@mail.com\", name: \"Fred\", phone: \"+31 6 5678 1234\"}\n    iex> Marker.Encoder.encode c\n    {:safe, \"   name:   Fred    email:   freddy@mail.com    phone:   +31 6 5678 1234   \"}","ref":"Marker.Encoder.html#module-example"},{"type":"function","title":"Marker.Encoder.encode/1","doc":"","ref":"Marker.Encoder.html#encode/1"},{"type":"type","title":"Marker.Encoder.t/0","doc":"All the types that implement this protocol.","ref":"Marker.Encoder.html#t:t/0"},{"type":"module","title":"Marker.HTML","doc":"All HTML elements are generated in this module.\nTo use the element macros outside of components and templates, use `use Marker.HTML` instead of `import Marker.HTML` to import them in to the current scope.\nThe `use` macro automatically handles any ambiguities between html elements and the funcions from `Kernel`. `Kernel.div/2` for example is unimported to allow the use of the `div` element.\nIf you still need to use `Kernel.div/2`, just call it as `Kernel.div(20, 2)`","ref":"Marker.HTML.html"},{"type":"macro","title":"Marker.HTML.a/2","doc":"","ref":"Marker.HTML.html#a/2"},{"type":"macro","title":"Marker.HTML.abbr/2","doc":"","ref":"Marker.HTML.html#abbr/2"},{"type":"macro","title":"Marker.HTML.address/2","doc":"","ref":"Marker.HTML.html#address/2"},{"type":"macro","title":"Marker.HTML.area/2","doc":"","ref":"Marker.HTML.html#area/2"},{"type":"macro","title":"Marker.HTML.article/2","doc":"","ref":"Marker.HTML.html#article/2"},{"type":"macro","title":"Marker.HTML.aside/2","doc":"","ref":"Marker.HTML.html#aside/2"},{"type":"macro","title":"Marker.HTML.audio/2","doc":"","ref":"Marker.HTML.html#audio/2"},{"type":"macro","title":"Marker.HTML.b/2","doc":"","ref":"Marker.HTML.html#b/2"},{"type":"macro","title":"Marker.HTML.base/2","doc":"","ref":"Marker.HTML.html#base/2"},{"type":"macro","title":"Marker.HTML.bdi/2","doc":"","ref":"Marker.HTML.html#bdi/2"},{"type":"macro","title":"Marker.HTML.bdo/2","doc":"","ref":"Marker.HTML.html#bdo/2"},{"type":"macro","title":"Marker.HTML.blockquote/2","doc":"","ref":"Marker.HTML.html#blockquote/2"},{"type":"macro","title":"Marker.HTML.body/2","doc":"","ref":"Marker.HTML.html#body/2"},{"type":"macro","title":"Marker.HTML.br/2","doc":"","ref":"Marker.HTML.html#br/2"},{"type":"macro","title":"Marker.HTML.button/2","doc":"","ref":"Marker.HTML.html#button/2"},{"type":"macro","title":"Marker.HTML.canvas/2","doc":"","ref":"Marker.HTML.html#canvas/2"},{"type":"macro","title":"Marker.HTML.caption/2","doc":"","ref":"Marker.HTML.html#caption/2"},{"type":"macro","title":"Marker.HTML.cite/2","doc":"","ref":"Marker.HTML.html#cite/2"},{"type":"macro","title":"Marker.HTML.code/2","doc":"","ref":"Marker.HTML.html#code/2"},{"type":"macro","title":"Marker.HTML.col/2","doc":"","ref":"Marker.HTML.html#col/2"},{"type":"macro","title":"Marker.HTML.colgroup/2","doc":"","ref":"Marker.HTML.html#colgroup/2"},{"type":"macro","title":"Marker.HTML.content/2","doc":"","ref":"Marker.HTML.html#content/2"},{"type":"macro","title":"Marker.HTML.data/2","doc":"","ref":"Marker.HTML.html#data/2"},{"type":"macro","title":"Marker.HTML.datalist/2","doc":"","ref":"Marker.HTML.html#datalist/2"},{"type":"macro","title":"Marker.HTML.dd/2","doc":"","ref":"Marker.HTML.html#dd/2"},{"type":"macro","title":"Marker.HTML.del/2","doc":"","ref":"Marker.HTML.html#del/2"},{"type":"macro","title":"Marker.HTML.details/2","doc":"","ref":"Marker.HTML.html#details/2"},{"type":"macro","title":"Marker.HTML.dfn/2","doc":"","ref":"Marker.HTML.html#dfn/2"},{"type":"macro","title":"Marker.HTML.div/2","doc":"","ref":"Marker.HTML.html#div/2"},{"type":"macro","title":"Marker.HTML.dl/2","doc":"","ref":"Marker.HTML.html#dl/2"},{"type":"macro","title":"Marker.HTML.dt/2","doc":"","ref":"Marker.HTML.html#dt/2"},{"type":"macro","title":"Marker.HTML.em/2","doc":"","ref":"Marker.HTML.html#em/2"},{"type":"macro","title":"Marker.HTML.embed/2","doc":"","ref":"Marker.HTML.html#embed/2"},{"type":"macro","title":"Marker.HTML.fieldset/2","doc":"","ref":"Marker.HTML.html#fieldset/2"},{"type":"macro","title":"Marker.HTML.figcaption/2","doc":"","ref":"Marker.HTML.html#figcaption/2"},{"type":"macro","title":"Marker.HTML.figure/2","doc":"","ref":"Marker.HTML.html#figure/2"},{"type":"macro","title":"Marker.HTML.footer/2","doc":"","ref":"Marker.HTML.html#footer/2"},{"type":"macro","title":"Marker.HTML.form/2","doc":"","ref":"Marker.HTML.html#form/2"},{"type":"macro","title":"Marker.HTML.h1/2","doc":"","ref":"Marker.HTML.html#h1/2"},{"type":"macro","title":"Marker.HTML.h2/2","doc":"","ref":"Marker.HTML.html#h2/2"},{"type":"macro","title":"Marker.HTML.h3/2","doc":"","ref":"Marker.HTML.html#h3/2"},{"type":"macro","title":"Marker.HTML.h4/2","doc":"","ref":"Marker.HTML.html#h4/2"},{"type":"macro","title":"Marker.HTML.h5/2","doc":"","ref":"Marker.HTML.html#h5/2"},{"type":"macro","title":"Marker.HTML.h6/2","doc":"","ref":"Marker.HTML.html#h6/2"},{"type":"macro","title":"Marker.HTML.head/2","doc":"","ref":"Marker.HTML.html#head/2"},{"type":"macro","title":"Marker.HTML.header/2","doc":"","ref":"Marker.HTML.html#header/2"},{"type":"macro","title":"Marker.HTML.hr/2","doc":"","ref":"Marker.HTML.html#hr/2"},{"type":"macro","title":"Marker.HTML.html/2","doc":"","ref":"Marker.HTML.html#html/2"},{"type":"macro","title":"Marker.HTML.i/2","doc":"","ref":"Marker.HTML.html#i/2"},{"type":"macro","title":"Marker.HTML.iframe/2","doc":"","ref":"Marker.HTML.html#iframe/2"},{"type":"macro","title":"Marker.HTML.img/2","doc":"","ref":"Marker.HTML.html#img/2"},{"type":"macro","title":"Marker.HTML.input/2","doc":"","ref":"Marker.HTML.html#input/2"},{"type":"macro","title":"Marker.HTML.ins/2","doc":"","ref":"Marker.HTML.html#ins/2"},{"type":"macro","title":"Marker.HTML.kbd/2","doc":"","ref":"Marker.HTML.html#kbd/2"},{"type":"macro","title":"Marker.HTML.keygen/2","doc":"","ref":"Marker.HTML.html#keygen/2"},{"type":"macro","title":"Marker.HTML.label/2","doc":"","ref":"Marker.HTML.html#label/2"},{"type":"macro","title":"Marker.HTML.legend/2","doc":"","ref":"Marker.HTML.html#legend/2"},{"type":"macro","title":"Marker.HTML.li/2","doc":"","ref":"Marker.HTML.html#li/2"},{"type":"macro","title":"Marker.HTML.link/2","doc":"","ref":"Marker.HTML.html#link/2"},{"type":"macro","title":"Marker.HTML.main/2","doc":"","ref":"Marker.HTML.html#main/2"},{"type":"macro","title":"Marker.HTML.map/2","doc":"","ref":"Marker.HTML.html#map/2"},{"type":"macro","title":"Marker.HTML.mark/2","doc":"","ref":"Marker.HTML.html#mark/2"},{"type":"macro","title":"Marker.HTML.menu/2","doc":"","ref":"Marker.HTML.html#menu/2"},{"type":"macro","title":"Marker.HTML.menuitem/2","doc":"","ref":"Marker.HTML.html#menuitem/2"},{"type":"macro","title":"Marker.HTML.meta/2","doc":"","ref":"Marker.HTML.html#meta/2"},{"type":"macro","title":"Marker.HTML.meter/2","doc":"","ref":"Marker.HTML.html#meter/2"},{"type":"macro","title":"Marker.HTML.nav/2","doc":"","ref":"Marker.HTML.html#nav/2"},{"type":"macro","title":"Marker.HTML.noscript/2","doc":"","ref":"Marker.HTML.html#noscript/2"},{"type":"macro","title":"Marker.HTML.object/2","doc":"","ref":"Marker.HTML.html#object/2"},{"type":"macro","title":"Marker.HTML.ol/2","doc":"","ref":"Marker.HTML.html#ol/2"},{"type":"macro","title":"Marker.HTML.optgroup/2","doc":"","ref":"Marker.HTML.html#optgroup/2"},{"type":"macro","title":"Marker.HTML.option/2","doc":"","ref":"Marker.HTML.html#option/2"},{"type":"macro","title":"Marker.HTML.output/2","doc":"","ref":"Marker.HTML.html#output/2"},{"type":"macro","title":"Marker.HTML.p/2","doc":"","ref":"Marker.HTML.html#p/2"},{"type":"macro","title":"Marker.HTML.param/2","doc":"","ref":"Marker.HTML.html#param/2"},{"type":"macro","title":"Marker.HTML.pre/2","doc":"","ref":"Marker.HTML.html#pre/2"},{"type":"macro","title":"Marker.HTML.progress/2","doc":"","ref":"Marker.HTML.html#progress/2"},{"type":"macro","title":"Marker.HTML.q/2","doc":"","ref":"Marker.HTML.html#q/2"},{"type":"macro","title":"Marker.HTML.rp/2","doc":"","ref":"Marker.HTML.html#rp/2"},{"type":"macro","title":"Marker.HTML.rt/2","doc":"","ref":"Marker.HTML.html#rt/2"},{"type":"macro","title":"Marker.HTML.ruby/2","doc":"","ref":"Marker.HTML.html#ruby/2"},{"type":"macro","title":"Marker.HTML.s/2","doc":"","ref":"Marker.HTML.html#s/2"},{"type":"macro","title":"Marker.HTML.samp/2","doc":"","ref":"Marker.HTML.html#samp/2"},{"type":"macro","title":"Marker.HTML.script/2","doc":"","ref":"Marker.HTML.html#script/2"},{"type":"macro","title":"Marker.HTML.section/2","doc":"","ref":"Marker.HTML.html#section/2"},{"type":"macro","title":"Marker.HTML.select/2","doc":"","ref":"Marker.HTML.html#select/2"},{"type":"macro","title":"Marker.HTML.shadow/2","doc":"","ref":"Marker.HTML.html#shadow/2"},{"type":"macro","title":"Marker.HTML.small/2","doc":"","ref":"Marker.HTML.html#small/2"},{"type":"macro","title":"Marker.HTML.source/2","doc":"","ref":"Marker.HTML.html#source/2"},{"type":"macro","title":"Marker.HTML.span/2","doc":"","ref":"Marker.HTML.html#span/2"},{"type":"macro","title":"Marker.HTML.string/2","doc":"","ref":"Marker.HTML.html#string/2"},{"type":"macro","title":"Marker.HTML.style/2","doc":"","ref":"Marker.HTML.html#style/2"},{"type":"macro","title":"Marker.HTML.sub/2","doc":"","ref":"Marker.HTML.html#sub/2"},{"type":"macro","title":"Marker.HTML.summary/2","doc":"","ref":"Marker.HTML.html#summary/2"},{"type":"macro","title":"Marker.HTML.sup/2","doc":"","ref":"Marker.HTML.html#sup/2"},{"type":"macro","title":"Marker.HTML.table/2","doc":"","ref":"Marker.HTML.html#table/2"},{"type":"macro","title":"Marker.HTML.tbody/2","doc":"","ref":"Marker.HTML.html#tbody/2"},{"type":"macro","title":"Marker.HTML.td/2","doc":"","ref":"Marker.HTML.html#td/2"},{"type":"macro","title":"Marker.HTML.template/2","doc":"","ref":"Marker.HTML.html#template/2"},{"type":"macro","title":"Marker.HTML.textarea/2","doc":"","ref":"Marker.HTML.html#textarea/2"},{"type":"macro","title":"Marker.HTML.tfoot/2","doc":"","ref":"Marker.HTML.html#tfoot/2"},{"type":"macro","title":"Marker.HTML.th/2","doc":"","ref":"Marker.HTML.html#th/2"},{"type":"macro","title":"Marker.HTML.thead/2","doc":"","ref":"Marker.HTML.html#thead/2"},{"type":"macro","title":"Marker.HTML.time/2","doc":"","ref":"Marker.HTML.html#time/2"},{"type":"macro","title":"Marker.HTML.title/2","doc":"","ref":"Marker.HTML.html#title/2"},{"type":"macro","title":"Marker.HTML.tr/2","doc":"","ref":"Marker.HTML.html#tr/2"},{"type":"macro","title":"Marker.HTML.track/2","doc":"","ref":"Marker.HTML.html#track/2"},{"type":"macro","title":"Marker.HTML.u/2","doc":"","ref":"Marker.HTML.html#u/2"},{"type":"macro","title":"Marker.HTML.ul/2","doc":"","ref":"Marker.HTML.html#ul/2"},{"type":"macro","title":"Marker.HTML.var/2","doc":"","ref":"Marker.HTML.html#var/2"},{"type":"macro","title":"Marker.HTML.video/2","doc":"","ref":"Marker.HTML.html#video/2"},{"type":"macro","title":"Marker.HTML.wbr/2","doc":"","ref":"Marker.HTML.html#wbr/2"},{"type":"macro","title":"Marker.HTML.xmp/2","doc":"","ref":"Marker.HTML.html#xmp/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}